AttrMaxQueueLength

Struct AttrMaxQueueLength 

pub struct AttrMaxQueueLength { /* private fields */ }
VI_ATTR_MAX_QUEUE_LENGTH specifies the maximum number of events that can be queued at any time on the given session. Events that occur after the queue has become full will be discarded. VI_ATTR_MAX_QUEUE_LENGTH is a Read/Write attribute until the first time viEnableEvent() is called on a session. Thereafter, this attribute is Read Only.

Implementations