pub struct AttrRsrcLockState { /* private fields */ }Expand description
VI_ATTR_RSRC_LOCK_STATE indicates the current locking state of the resource. The resource can be unlocked, locked with an exclusive lock, or locked with a shared lock.
Implementations
Sourceimpl AttrRsrcLockState
impl AttrRsrcLockState
pub fn into_inner(self) -> ViAccessMode
Sourceimpl AttrRsrcLockState
impl AttrRsrcLockState
pub const VI_NO_LOCK: Self
pub const VI_EXCLUSIVE_LOCK: Self
pub const VI_SHARED_LOCK: Self
pub unsafe fn new_unchecked(value: ViAccessMode) -> Self