pub struct AttrMaxQueueLength { /* private fields */ }Expand description
VI_ATTR_MAX_QUEUE_LENGTH specifies the maximum number of events that can be queued at any time on the given session. Events that occur after the queue has become full will be discarded. VI_ATTR_MAX_QUEUE_LENGTH is a Read/Write attribute until the first time viEnableEvent() is called on a session. Thereafter, this attribute is Read Only.
Implementations
Sourceimpl AttrMaxQueueLength
impl AttrMaxQueueLength
pub fn into_inner(self) -> ViUInt32
Sourceimpl AttrMaxQueueLength
impl AttrMaxQueueLength
pub unsafe fn new_unchecked(value: ViUInt32) -> Self
pub fn new_checked(value: ViUInt32) -> Option<Self>